@@ -1,4 +1,4 @@
-t <- structure(ISOdate(2021, 05, 27), names="t")
+t <- structure(ISOdatetime(2021, 05, 27, 12, 0, 0), names="t")  # default time zone
 
 # different calendar/locale - easy with stringx:
 
@@ -17,6 +17,9 @@ E(
     c(t="Donnerstag")
 )
 
+
+t <- structure(ISOdatetime(2021, 05, 27, 12, 0, 0, tz="GMT"), names="t")
+
 E(
     strftime(t, "%H:%M:%S", tz="UTC", usetz=TRUE),
     P(c(t="12:00:00"), warning=TRUE)
